@@ -9,4 +9,7 @@ const (
 	CMD     = "cmd"
 	NU      = "nu"
 	GENERIC = "shell"
+	TCSH    = "tcsh"
+	ELVISH  = "elvish"
+	XONSH   = "xonsh"
 )
