@@ -6,4 +6,4 @@ func hideFile(_ string) error {
 	return nil
 }
 
-func updateRegistry(_ string) {}
+func updateRegistry(_, _ string) {}
